smart: speed up installation (reduce 28% ~ 57%)
Get series with b4
b4 am [email protected]Versions newest first
- v1 Latest1 patch 1 replyIn review
Patches in v1 No applies recorded yet
| # | Subject and files | Size | Replies | Applied |
|---|---|---|---|---|
| 1/1 | smart:cache.py: getPackages() matches name + archmeta/ meta/ | +44 | 1 reply |
Reviews trailers per patch
No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.
Cover letter [PATCH 0/1] smart: speed up installation (reduce 28% ~ 57%)
Here is the test result:
MACHINE = "qemux86-64"
- When multilib enabled:
$ bitbake core-image-sato -cpopulate_sdk
time: 6m5s -> 2m34s (Reduce 57% ) $ bitbake core-image-minimal -cpopulate_sdk
time: 2m1s -> 1m26s (Reduce 28% ) $ bitbake core-image-sato-sdk
time: 10m15s -> 7m12s (Reduce 29% )- When multilib NOT enabled:
$ bitbake core-image-sato-sdk -cpopulate_sdk
time: 4m25s -> 2m28s (Reduce 44% )// Robert
The following changes since commit 16957f5f1de0f1fb4052d5aef93ee10c893f4a38:
oeqa/selftest/wic: Use SetupLocal instead of Setup (2015-10-01 07:40:37 +0100)
are available in the git repository at:
git://git.openembedded.org/openembedded-core-contrib rbt/smart
http://cgit.openembedded.org/cgit.cgi/openembedded-core-contrib/log/?h=rbt/smart
Robert Yang (1):
smart:cache.py: getPackages() matches name + arch
...cache.py-getPackages-matches-name-version.patch | 43 ++++++++++++++++++++ meta/recipes-devtools/python/python-smartpm_git.bb | 1 + 2 files changed, 44 insertions(+) create mode 100644 meta/recipes-devtools/python/python-smartpm/smart-cache.py-getPackages-matches-name-version.patch
Signature · 1 line
1.7.9.5